.. openspace documentation master file, created by
   sphinx-quickstart on Sun Dec 25 13:17:15 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

openspace astrodynamics toolkit
===============================

.. toctree::
    :maxdepth: 2

    modules
    examples
    references
